from django.conf.urls import patterns, url

from .views import ArticleView, ArticleList


urlpatterns = patterns('',
    url(r'^$', ArticleList.as_view(), name='list_articles'),
    url(r'^(?P<slug>[\w-]+)/$', ArticleView.as_view(), name='view_article'),
)



from django.views.generic import DetailView, ListView

from .models import Article


class ArticleList(ListView):
    model = Article

    def get_queryset(self):
        qs = self.model.objects.all()
        if not self.request.user.is_staff:
            qs = qs.filter(published=True)
        return qs


class ArticleView(DetailView):
    model = Article

    def get_queryset(self):
        qs = self.model.objects.all()
        if not self.request.user.is_staff:
            qs = qs.filter(published=True)
        return qs



from setuptools import setup


setup(name='django-chalk',
      version='0.1',
      author='Kevin Dias',
      author_email='kevin@kevindias.com',
      description='Simple reStructuredText blogging for Django',
      url='http://kevindias.com/projects/chalk/',
      packages=['chalk'],
      install_requires=['docutils>=0.9', 'pygments>=1.4'],
      classifiers=['Development Status :: 3 - Alpha',
                   'Environment :: Web Environment',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: BSD License',
                   'Operating System :: OS Independent',
                   'Programming Language :: Python',
                   'Framework :: Django',
                   'Topic :: Utilities'],
      zip_safe=False,
)
